#
# spec file for package python-pyte
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
%bcond_with     test
Name:           python-pyte
Version:        0.7.0
Release:        lp151.2.2
Summary:        VTXXX-compatible linux terminal emulator
License:        LGPL-3.0
Group:          Development/Languages/Python
Url:            https://github.com/selectel/pyte
Source:         https://files.pythonhosted.org/packages/source/p/pyte/pyte-%{version}.tar.gz
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module pytest-runner}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wcwidth}
BuildRequires:  python-rpm-macros
Requires:       python-wcwidth
BuildArch:      noarch
%python_subpackages

%description
An in-memory VTXXX-compatible terminal emulator supporting VT100 and
other DEC VTs between 1970 and 1995. pyte can be used to:

* screen scrape terminal apps, for example htop or aptitude.
* write terminal emulators; either with a graphical (xterm, rxvt)
  or a web interface, like AjaxTerm.

%prep
%setup -q -n pyte-%{version}

%build
%python_build

%install
%python_install

%if %{with test}
%check
%python_exec setup.py test
%endif

%files %{python_files}
%defattr(-,root,root,-)
%doc LICENSE README AUTHORS CHANGES docs/*rst
%{python_sitelib}/*

%changelog
* Fri Nov  3 2017 arun@gmx.de
- update to version 0.7.0:
  * Removed deprecated "only" parameter of "Stream.attach".
  * Removed deprecated "encoding" parameter of "ByteStream".
  * Fixed "how == 3" handling in "DiffScreen.erase_in_display".
  * Deprecated "DiffScreen". Its functionality has been backported to
    the base "Screen" class.
  * Fixed a bug in "DiffScreen.draw" which incorrectly handled the
    case when the input of "draw" required several lines.
  * Fixed a bug in "Screen" which did not ignore "ESC (" argument in
    UTF8 mode. See issue #88 on GitHub.
  * Changed "Screen.resize" to do nothing if the requested size
    matches the current one.
  * Disallowed private mode for
    "Screen.report_device_attributes". This was causing an infinite
    loop in Emacs and Vim. See issue #81 on GitHub.
  * Fixed a bug in `OSC` parsing, which caused "Stream" to hang upon
    receiving a palette reset request "ESC ] R".
  * Changed "Screen.reset" not to reset `DECOM`. See discussion in
    issue #95 on Github.
  * Changed the first tabstop to be at the 9-th column. See PR #98 on
    GitHub. Thanks to @gordon-quad!
* Sun Sep  3 2017 jengelh@inai.de
- Replace python-curtsies description by python-pyte's.
* Thu Aug 31 2017 toddrme2178@gmail.com
- Update to 0.6.0
  * Optimized ``Stream.feed`` for plain-text input. The code was backported
    from ``pymux`` project by Jonathan Slenders.
  * Optimized ``Screen`` by changing ``Screen.buffer`` to dict-of-dicts. The
    idea was borrowed from ``pymux`` project by Jonathan Slenders. The
    implementation was done by @istarion.
  * Further optimized ``Stream._parser_fsm`` by forcing static binding between
    ``Stream`` events and ``Screen`` methods. The code was backported from
    ``pmux`` project by Jonathan Slenders.
  * Restricted ``Stream`` to a single listener and deprecated ``attach`` and
    ``detach``. The old logic can be emulated by a fanout proxy, forwarding
    events to a list of its listeners.
  * Replaced ``DebugStream`` with ``DebugScreen`` to workaround the single
    listener limitation (previsouly ``DebugStream`` implicitly added a
    listener when instantiated). Unlike other screens ``DebugScreen`` does
    not maintain any state.
  * Changed ``DebugScreen`` to emit JSON instead of custom text format.
  * Removed overly generic ``Screen.__before__`` and ``Screen.__after__``.
  * Renamed ``Screen.set_charset`` to a more appropriate
    ``Screen.define_charset``.
  * Added support for ECMA-035 `DOCS` command to ``ByteStream`` which no longer
    accepts ``encoding`` as an argument and instead sets it as instructed by
    `DOCS`. The default encoding is assumed to be UTF-8.
  * Added support for OSC sequences allowing to set terminal title and
    icon name.
  * Allowed 256 and 24bit colours in ``Screen.select_graphic_rendition``.
  * Added support for ``aixterm`` colours in ``Screen.select_graphic_rendition``,
    see issue #57 on GitHub.
  * Changed ``Screen.select_graphic_rendition`` to ignore 0 if it is
    given along with other attributes, ie ``"0;1;2"`` is now equivalent
    to ``"1;2"``.
  * Fixed rendering of multicolumn characters at ``Screen` boundaries.
    Thanks to @shaform! See PR #55 on GitHub.
  * Fixed ``Screen.display`` in the case of multicolumn characters. See
    issue #52 on GitHub.
  * Fixed `DECSTBM` handling in case of missing arguments. See issue #61 on
    GitHub.
  * Fixed the way ``Screen.cursor_up`` and ``Screen.cursor_down`` interact
    with the scrolling region. See #63 on GitHub.
  * Added a minimal web terminal example by @demiurg906. For a faster and
    more fully-featured version, see
    `demiurg906/pyte_gui <https://github.com/demiurg906/pyte_gui>`_.
  * Fixed ``Screen.cursor_back`` when called after the draw in the last column.
  * Fixed ``Screen.inser_characters`` when called with an argument larger
    than the number of columns. Thanks to @istarion! See PR #74 on GitHub.
  * Fixed ``Screen.erase_in_display`` which did not handle all values supported
    by ``TERM=linux``. See #80 on GitHub.
* Thu Aug 24 2017 jmatejek@suse.com
- singlespec auto-conversion
* Mon Aug 15 2016 badshah400@gmail.com
- Initial package.
